<?php
/*
* 2007-2013 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2011 PrestaShop SA
*  @version  Release: $Revision$
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_'))
exit;

class go_pl extends Module{
	function __construct(){
		$this->name = 'go_pl';
		$this->tab = 'Marketing';
		$this->version = '1.0.5';
		$this->author = 'GO.PL';
		$this->displayName = 'GO.PL';
		$this->module_key = '857jdhs847fjsdfvf72e6f1878d990b8';

		parent::__construct();

		if ($this->id AND !Configuration::get('GOPL_ID'))
			$this->warning = $this->l('You have not yet set your GO.PL ID');
		$this->description = $this->l('Integrate GO.PL script into your shop');
		$this->confirmUninstall = $this->l('Are you sure you want to delete your details ?');

		/** Backward compatibility */
		require(_PS_MODULE_DIR_.$this->name.'/backward_compatibility/backward.php');
	}

	function install(){
		if (!parent::install() ||
			!$this->registerHook('header') ||
			!$this->registerHook('ProductFooter') ||
			!$this->registerHook('shoppingCart') ||
			!$this->registerHook('Footer') ||
			!$this->registerHook('OrderConfirmation'))
			return false;
		return true;
	}

	function uninstall(){
	if (!Configuration::deleteByName('GOPL_ID') || !parent::uninstall())
		return false;
	return true;
	}

	public function getContent(){
		$output = '
			<h2>GO.PL RTB & MA module</h2>';
		if (Tools::isSubmit('submitGAnalytics') AND ($gai = Tools::getValue('GOPL_ID'))){
			Configuration::updateValue('GOPL_ID', $gai);
			
			if(isset($_POST['GOPL_DEBUG'])){
				$go_debug="DEBUG_ON";
				Configuration::updateValue('GOPL_DEBUG',$go_debug);
			}
			else{
				$go_debug="DEBUG_OFF";
				Configuration::updateValue('GOPL_DEBUG',$go_debug);
			}

			$output .= '
				<div class="conf confirm">
					<img src="../img/admin/ok.gif" alt="" title="" />
					'.$this->l('Settings updated').'
				</div>';
		}
		return $output.$this->displayForm();
	}

	public function displayForm(){
	$output = '
		<form action="'.Tools::safeOutput($_SERVER['REQUEST_URI']).'" method="post">
			<fieldset class="width2">
				<legend>
					<img src="../img/admin/cog.gif" alt="" class="middle" />'.$this->l('Settings').'
				</legend>
				<label>'.$this->l('Your GO.PL ID').'</label>
				<div class="margin-form">
					<input type="text" name="GOPL_ID" value="'.Tools::safeOutput(Tools::getValue('GOPL_ID', Configuration::get('GOPL_ID'))).'" />
					<p class="clear">'.$this->l('Example:').' 34f69f6a-78b3-448a-1234-60400debb334</p>
				</div>
				<label>'.$this->l('DEBUG Mode').'</label>
				<div class="margin-form">';
					if(Configuration::get('GOPL_DEBUG')=="DEBUG_ON"){
						$output.='
							<input type="checkbox" name="GOPL_DEBUG" value="'.Configuration::get('GOPL_DEBUG').'" checked="checked" />';
					}
					else{
						$output.='
							<input type="checkbox" name="GOPL_DEBUG" value="'.Configuration::get('GOPL_DEBUG').'" />';
					}
					$output.='
					<p class="clear">'.$this->l('Check this option only for GO.PL request!').'</p>
				</div>
				<center>
					<input type="submit" name="submitGAnalytics" value="'.$this->l('Update ID').'" class="button" />
				</center>
			</fieldset>
		</form>';
	/*
	$output .= '
	<fieldset class="space">
	<legend><img src="../img/admin/unknown.gif" alt="" class="middle" />'.$this->l('Help').'</legend>
	<h3>'.$this->l('The first step of tracking e-commerce transactions is to enable e-commerce reporting for your website\'s profile.').'</h3>
	'.$this->l('To enable e-Commerce reporting, please follow these steps:').'
	<ol>
	<li>'.$this->l('Log in to your account').'</li>
	<li>'.$this->l('Click Edit next to the profile you would like to enable.').'</li>
	<li>'.$this->l('On the Profile Settings page, click Edit (next to Main Website Profile Information).').'</li>
	<li>'.$this->l('Change the e-Commerce Website radio button from No to Yes').'</li>
	</ol>
	<h3>'.$this->l('To set up your goals, enter Goal Information:').'</h3>
	</fieldset>';
	*/
	return $output;
	}

	public function hookHeader($params){
		$output = '
			<script type="text/javascript">
				var goadservicesq = goadservicesq || [];
			</script>';
			if(Tools::getValue('email')){
			$email = trim(Tools::getValue('email'));
			$output .= "
			<script type=\"text/javascript\">
			try{
				var _fe  = _fe || [];
				_fe.push(['_partnerId','".Configuration::get('GOPL_MA_ID')."']);
				_fe.push(['_func','track']);
				_fe.push(['_email','".$email."']); 
					(function() {
						var fore = document.createElement('script'); fore.type = 'text/javascript'; fore.async = true;
						fore.src = 'https://rt.goadservices.com/js/4et.js?id_partner=".Configuration::get('GOPL_MA_ID')."';        
						var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(fore, s);
					})();
			}catch(e){console.log(e)}
			</script>";
		} 
		return $output;
	}

	public function hookProductFooter($params){
		global $cookie;
		
		$output = "
			<script type=\"text/javascript\">
				try {
				goadservicesq.push(
					[
						\"_PRODUCT\",
						{
							identifier: '".$params['product']['id']."',
							name: '".$params['product']['name']."'
						}
					]
				);
				} catch (e) {};
			</script>";
		return $output;
	}

	public function hookFooter($params){
		if(Configuration::get('GOPL_DEBUG')=="DEBUG_ON"){
			@include_once("https://t.goadservices.com/debug/".Configuration::get('GOPL_ID')."?format=php");
		}
		$output = "<script type=\"text/javascript\" async=\"true\" referrerpolicy=\"no-referrer-when-downgrade\" src=\"https://t.goadservices.com/tags/".Configuration::get('GOPL_ID')."?software_name=presta&software_version=".urlencode(_PS_VERSION_)."&plugin_version=".urlencode($this->version)."\"></script>";
		/*
		$user_email = null;
		if (in_array($this->context->controller->controller_type, array('front', 'modulefront'))) {
			$user_email = $this->context->customer->isLogged() ? $this->context->customer->email : null;
		}
		if ($user_email) {
			$output .= "
			<script type=\"text/javascript\">
				try{
					var _fe  = _fe || [];
					_fe.push(['_partnerId','".Configuration::get('GOPL_MA_ID')."']);
					_fe.push(['_func','track']);
					_fe.push(['_email','".$user_email."']);
						(function() {
							var fore = document.createElement('script'); fore.type = 'text/javascript'; fore.async = true;
							fore.src = 'https://rt.goadservices.com/js/4et.js?id_partner=".Configuration::get('GOPL_MA_ID')."';        
							var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(fore, s);
						})();
				}catch(e){console.log(e)}
			</script>";
		}*/
		return $output;
	}

	public function hookOrderConfirmation($params){
		global $cookie;
		$output = '';
		$order = $params['order'];
		#$output = "<!--\n".serialize($order)."\n-->";


		if (Validate::isLoadedObject($order)){
			$c = Currency::getCurrency($order->id_currency);     
			//amount: '".$order->total_paid."'
			$output .= "
			<script type=\"text/javascript\">  
			var goadservicesq = goadservicesq || [];  
			try {
				goadservicesq.push(
					[
						\"_ORDER\",
							{
								identifier: '".$order->id."',
								amount: '".$order->total_products_wt."',
								currency: '".$c['iso_code']."'
							},
						[";
				/* Order general informations */
				/* Product informations */	
						$products = $order->getProducts();					
						foreach ($products AS $product){
							$output .= "
							{
								identifier: '".$product['product_id']."',
								quantity: '".$product['product_quantity']."'
							},\n";
						}
						$output .= "
						{}
						]
					]
				);
				(function() {
					var goadservices = document.createElement('script');
					goadservices.type = 'text/javascript';
					goadservices.async = true;
					goadservices.src = 'https://t.goadservices.com/engine/".Configuration::get('GOPL_ID')."';
					var id_s = document.cookie.indexOf('__goadservices=');
					if (id_s != -1) {
						id_s += 15;
						var id_e = document.cookie.indexOf(';', id_s);
						if (id_e == -1) {
							id_e = document.cookie.length;
						}
						goadservices.src += '?id='+document.cookie.substring(id_s, id_e);
					}
					var s = document.getElementsByTagName('script')[0];
					s.parentNode.insertBefore(goadservices, s);
				})();
			} catch (e) {}
			</script>\n";  
		}   	
		return $output; 
	}

	public function hookShoppingCart($params){

		$cart = $params['cart'] ;
		$products = $cart->getProducts() ;
		$output = "
			<script type=\"text/javascript\">
				try {
					goadservicesq.push(
						[
							\"_BASKET\",
								[";
								// Dla kazdej pozycji w koszyku
								foreach($products as $product){					
									$output .= "
									{
										identifier: '".$product['id_product']."',
										quantity: '".$product['quantity']."',
										price: '".$product['price_wt']."',
									},";
								}
								$output .= "
								{}
								]
						]
					);
				} catch (e) {};
			</script>";
		return $output;
	}

	function hookOrderConfirmationx($params){
		// Setting parameters
		$parameters = Configuration::getMultiple(array('PS_LANG_DEFAULT'));

		$order = $params['objOrder'];
		if (Validate::isLoadedObject($order)){
			$deliveryAddress = new Address(intval($order->id_address_delivery));

			$conversion_rate = 1;
			if ($order->id_currency != Configuration::get('PS_CURRENCY_DEFAULT')){
				$currency = new Currency(intval($order->id_currency));
				$conversion_rate = floatval($currency->conversion_rate);
			}

			// Order general information
			$trans = array(
				'id' => intval($order->id),// order ID - required
				'store' => htmlentities(Configuration::get('PS_SHOP_NAME')),// affiliation or store name
				'amount' => Tools::ps_round(floatval($order->$order) / floatval($conversion_rate), 2),// total - required
				'shipping' => Tools::ps_round(floatval($order->total_shipping) / floatval($conversion_rate), 2),// shipping
			);

			// Product information
			$products = $order->getProducts();
			foreach ($products AS $product){
				$category = Db::getInstance()->getRow('
				SELECT name FROM `'._DB_PREFIX_.'category_lang` , '._DB_PREFIX_.'product 
				WHERE `id_product` = '.intval($product['product_id']).' AND `id_category_default` = `id_category` 
				AND `id_lang` = '.intval($parameters['PS_LANG_DEFAULT']));

				$items[] = array(
					'OrderId' => intval($order->id),// order ID - required
					'identyfier' => addslashes($product['product_id']),// SKU/code - required
					'Product' => addslashes($product['product_name']),// product name
					'Category' => addslashes($category['name']),// category or variation
					'Price' => Tools::ps_round(floatval($product['product_price_wt']) / floatval($conversion_rate), 2),// unit price - required
					'Quantity' => addslashes(intval($product['product_quantity']))//quantity - required
				);
			}
			$GOPL_ID = Configuration::get('GOPL_ID');
			$GOPL_MA_ID = Configuration::get('GOPL_MA_ID');
			$GOPL_DEBUG = Configuration::get('GOPL_DEBUG');

			$this->context->smarty->assign('items', $items);
			$this->context->smarty->assign('trans', $trans);
			$this->context->smarty->assign('GOPL_ID', $GOPL_ID);
			$this->context->smarty->assign('GOPL_MA_ID', $GOPL_MA_ID);
			$this->context->smarty->assign('GOPL_DEBUG', $GOPL_DEBUG);

			$this->context->smarty->assign('isOrder', true);
			return $this->display(__FILE__, 'header.tpl');
		}
	}
}